from Small_letters import *
from Capital_letters import *
from Numbers import *
from Special_characters import *


def pattern(text,char='*'):

    text = list(text)

    for i in text:

        if (i == 'A'):
            pattern_A(char)

        if (i == 'B'):
            pattern_B(char)

        if (i == 'C'):
            pattern_C(char)

        if (i == 'D'):
            pattern_D(char)

        if (i == 'E'):
            pattern_E(char)

        if (i == 'F'):
            pattern_F(char)

        if (i == 'G'):
            pattern_G(char)

        if (i == 'H'):
            pattern_H(char)

        if (i == 'I'):
            pattern_I(char)

        if (i == 'J'):
            pattern_J(char)

        if (i == 'K'):
            pattern_K(char)

        if (i == 'L'):
            pattern_L(char)

        if (i == 'M'):
            pattern_M(char)

        if (i == 'N'):
            pattern_N(char)

        if (i == 'O'):
            pattern_O(char)

        if (i == 'P'):
            pattern_P(char)

        if (i == 'Q'):
            pattern_Q(char)

        if (i == 'R'):
            pattern_R(char)

        if (i == 'S'):
            pattern_S(char)

        if (i == 'T'):
            pattern_T(char)

        if (i == 'U'):
            pattern_U(char)

        if (i == 'V'):
            pattern_V(char)

        if (i == 'W'):
            pattern_W(char)

        if (i == 'X'):
            pattern_X(char)

        if (i == 'Y'):
            pattern_Y(char)

        if (i == 'Z'):
            pattern_Z(char)

        ####################

        if (i == 'a'):
            pattern_a(char)

        if (i == 'b'):
            pattern_b(char)

        if (i == 'c'):
            pattern_c(char)

        if (i == 'd'):
            pattern_d(char)

        if (i == 'e'):
            pattern_e(char)

        if (i == 'f'):
            pattern_f(char)

        if (i == 'g'):
            pattern_g(char)

        if (i == 'h'):
            pattern_h(char)

        if (i == 'i'):
            pattern_i(char)

        if (i == 'j'):
            pattern_j(char)

        if (i == 'k'):
            pattern_k(char)

        if (i == 'l'):
            pattern_l(char)

        if (i == 'm'):
            pattern_m(char)

        if (i == 'n'):
            pattern_n(char)

        if (i == 'o'):
            pattern_o(char)

        if (i == 'p'):
            pattern_p(char)

        if (i == 'q'):
            pattern_q(char)

        if (i == 'r'):
            pattern_r(char)

        if (i == 's'):
            pattern_s(char)

        if (i == 't'):
            pattern_t(char)

        if (i == 'u'):
            pattern_u(char)

        if (i == 'v'):
            pattern_v(char)

        if (i == 'w'):
            pattern_w(char)

        if (i == 'x'):
            pattern_x(char)

        if (i == 'y'):
            pattern_y(char)

        if (i == 'z'):
            pattern_z(char)

        ####################

        if (i == '0'):
            pattern_0(char)

        if (i == '1'):
            pattern_1(char)

        if (i == '2'):
            pattern_2(char)

        if (i == '3'):
            pattern_3(char)

        if (i == '4'):
            pattern_4(char)

        if (i == '5'):
            pattern_5(char)

        if (i == '6'):
            pattern_6(char)

        if (i == '7'):
            pattern_7(char)

        if (i == '8'):
            pattern_8(char)

        if (i == '9'):
            pattern_9(char)

        #####################

        if (i == '+'):
            pattern_plus(char)

        if (i == '-'):
            pattern_minus(char)

        if (i == '*'):
            pattern_multiply(char)

        if (i == '/'):
            pattern_divide(char)

        if (i == '_'):
            pattern_underscore(char)

        print()


